@@ -31,7 +31,6 @@
 #include "attachmenthandler.h"
 #include "calendarsupport_debug.h"
 #include "calendarsupport/utils.h"
-#include <kio_version.h>
 
 #include <ItemFetchJob>
 
@@ -110,11 +109,7 @@ Attachment AttachmentHandler::find(const QString &attachmentName, const Incidenc
     }
 
     if (a.isUri()) {
-#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
-        auto job = KIO::stat(QUrl(a.uri()), KIO::StatJob::SourceSide, 0);
-#else
         auto job = KIO::statDetails(QUrl(a.uri()), KIO::StatJob::SourceSide, KIO::StatBasic);
-#endif
 
         KJobWidgets::setWindow(job, d->mParent);
         if (!job->exec()) {
